##  Managing Collections
Users with the appropriate permissions can create and manage collections. To do this, on the dashboards, reports, or diagrams page, click Manage Collections at the bottom of the left-side panel. In the modal that appears, you can create, edit, reorder, and delete the following:
  * Collection groups
  * Collections
  * Subcollections


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiob91d419048ce4d65856058c97e9c713d_LowRes.png)
Managing Collections in the Manage Collections Modal
You can also open the Manage Collections modal from a collection page. To do this, in the upper-right corner, click the three-dot icon > Edit Collection. To move a collection, click the three-dot icon > Move.
